/*
 {$BRAND_NAME`}
 Copyright (c) ocProducts, 2004-2016
*/

.privileges input[type="button"] {
	width: 3em;
}

.privileges .permission_field_name_column {
	width: 25em;
}

.privileges th {
	text-align: {!en_left};
}

.privileges td {
	text-align: {!en_right};
	vertical-align: middle;
	padding-{!en_right}: 4px; /* Fixes firefox bug of scrollbar appearing for .wide_table_wrap */
}

.permission_header_cell {
	vertical-align: middle;
}

.match_key_name_column {
	width: 15em;
}

.heading_group {
	display: block;
	text-align: right;
}

.heading_presets {
	margin-top: 0.5em;
	display: block;
	text-align: left;
}

@keyframes active_repeating_fading {
	from {
		opacity: 1.0;
	}

	to {
		opacity: 0.6;
	}
}

.active_repeating {
	animation-duration: 1s;
	animation-name: active_repeating_fading;
	animation-iteration-count: infinite;
	animation-direction: alternate;
}
